<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://cookieform.pl
 * @since      1.0.0
 *
 * @package    Cookie_Form_Plugin
 * @subpackage Cookie_Form_Plugin/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Cookie_Form_Plugin
 * @subpackage Cookie_Form_Plugin/admin
 * @author     Cookie Form <bok@cookieform.pl>
 */
class Cookie_Form_Plugin_Admin
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of this plugin.
     * @param string $version The version of this plugin.
     * @since    1.0.0
     */
    public function __construct($plugin_name, $version)
    {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Cookie_Form_Plugin_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Cookie_Form_Plugin_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/cookie-form-plugin-admin.css', array(), $this->version, 'all');

    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Cookie_Form_Plugin_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Cookie_Form_Plugin_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

//        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/cookie-form-plugin-admin.js', array('jquery'), $this->version, false);

    }

    /**
     * Register settings group
     *
     * @return void
     */
    public function register_settings()
    {
        register_setting('cookie-form-settings-group', 'cookie-form-uuid');
    }

    /**
     * Register plugin options page
     *
     * @return void
     */
    public function add_settings_page()
    {
        add_options_page('Cookie Form Settings', 'Cookie Form', 'manage_options', 'cookie-form-plugin', [get_called_class(), "settings_page_content"]);
    }

    public function add_action_links($links) {
        $additionalLinks = array(
                '<a href="' . admin_url( 'options-general.php?page=cookie-form-plugin' ) . '">Ustawienia</a>',
            );

        return array_merge( $links, $additionalLinks );
    }

    /**
     * Admin settings page content
     *
     * @return void
     */
    public function settings_page_content()
    {
        ?>
        <div class="wrap">
            <img src="<?= plugin_dir_url(__FILE__); ?>assets/logo.svg" alt="CookieForm">
            <h3>
                Cookieform to wtyczka służąca do wyświetlania deklaracji, zarządzania oraz wykrywania nowych plików 'Cookies' na Twojej stronie.
            </h3>
            <h3>
                Aby móc korzystać z dodatku wejdź na stronę system.cookieform.pl i załóż darmowe konto.
                Następnie przejdź do zakładki "Domeny" i kliknij w "Dodaj na stronie".
                W oknie modalnym pojawi się Twój unikalny kod klienta, który należy wkleić w poniższe pole. Teraz wystarczy zapisać zmiany ... i gotowe!
            </h3>
            <form method="post" action="options.php">
                <?php settings_fields('cookie-form-settings-group'); ?>
                <table class="form-table">
                    <tr>
                        <th scope="row">Kod UUID</th>
                        <td><input type="text" name="cookie-form-uuid"
                                   value="<?php echo esc_attr(get_option('cookie-form-uuid')); ?>"/></td>
                    </tr>
                </table>

                <?php submit_button(); ?>

            </form>
        </div>
        <?php
    }
}
