<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://cookieform.pl
 * @since      1.0.0
 *
 * @package    Cookie_Form_Plugin
 * @subpackage Cookie_Form_Plugin/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Cookie_Form_Plugin
 * @subpackage Cookie_Form_Plugin/public
 * @author     Cookie Form <kontakt@cookieform.pl>
 */
class Cookie_Form_Plugin_Public
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * UUID code
     *
     * @var string
     */
    private $uuid;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of the plugin.
     * @param string $version The version of this plugin.
     * @since    1.0.0
     */
    public function __construct($plugin_name, $version)
    {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

    }

    /**
     * @return void
     */
    public function run()
    {
        if ($this->is_uuid_set()) $this->inject_code();
    }

    /**
     * Check if uuid is set in the wp_options. If yes, set $this->uuid
     *
     * @return bool
     */
    private function is_uuid_set()
    {
        $uuid = esc_attr(get_option('cookie-form-uuid'));
        if ($uuid) {
            $this->uuid = $uuid;
            return true;
        }
        return false;
    }

    /**
     * Code that will be injected
     *
     * @return void
     */
    private function inject_code()
    {
        include "partials/cookie-form-plugin-public-display.php";
    }

}
